start

# --multifile=MULTIFILESTYLE

This options determines how the POT/PO files are spli from the source files. In many cases you have source files that generate either too many small files or one large files which you would rather see split up into smaller files.

## single

Output individual files.

## toplevel

Split the source files at the top level. Ie you see a number of top level files.

## onefiles

One large file instead of many smaller files.